@@ -3,6 +3,13 @@ from typing import List, Union
 from zeno.classes.base import CamelModel
 
 
+class PointsColors(CamelModel):
+    color: List[int]
+    domain: List[Union[int, float, str]]
+    # "nominal" or "continuous" or "boolean"
+    data_type: str
+
+
 class Points2D(CamelModel):
     x: List[float]
     y: List[float]
@@ -11,4 +18,4 @@ class Points2D(CamelModel):
     ids: List[str]
     domain: List[Union[int, float, str]]
     # "nominal" or "continuous" or "boolean"
-    dataType: str
+    data_type: str
